==> auto-ui-2.4.55.tgz: package/es/cell/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { Link } from 'react-router-dom';
import IconArrow from '../icon/arrow';
import './style/index.scss';
var CellRow = function (props) {
    var value = props.value, arrow = props.arrow, onClick = props.onClick, href = props.href, to = props.to, activable = props.activable, className = props.className, children = props.children, title = props.title, dividerIndent = props.dividerIndent, indentLine = props.indentLine, endIndentLine = props.endIndentLine, addonAfter = props.addonAfter, otherProps = __rest(props, ["value", "arrow", "onClick", "href", "to", "activable", "className", "children", "title", "dividerIndent", "indentLine", "endIndentLine", "addonAfter"]);
    if (indentLine || endIndentLine) {
        // TODO: 需要废弃这两个属性
        console.warn('indentLine与endIndentLine将被废弃，请使用dividerIndent代替');
    }
    // 兼容老的属性
    // TODO: indentLine 和 endIndentLine 废弃后，该部分代码需要一起删除
    var finalDividerIndent = dividerIndent;
    if (!finalDividerIndent && (indentLine || endIndentLine)) {
        if (indentLine && !endIndentLine) {
            finalDividerIndent = 'left';
        }
        else {
            finalDividerIndent = 'both';
        }
    }
    var composeClassName = cn('x-cell__row', className, {
        'x-cell__row--activable': onClick || to || href || activable,
        'x-cell__row--arrow': arrow,
        'x-cell__row--divider-indent-left': finalDividerIndent === 'left',
        'x-cell__row--divider-indent-both': finalDividerIndent === 'both',
    });
    var content = function () { return (React.createElement(React.Fragment, null,
        title && React.createElement("label", null, title),
        children,
        addonAfter && React.createElement("span", { className: "x-cell__addon-after" }, addonAfter),
        arrow && React.createElement(IconArrow, { className: "x-cell__arrow" }))); };
    if (onClick) {
        var onClickHandle = function () { return onClick(value); };
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, onClick: onClickHandle }), content()));
    }
    if (to) {
        return (React.createElement(Link, __assign({}, otherProps, { className: composeClassName, to: to }), content()));
    }
    if (href) {
        return (React.createElement("a", __assign({}, otherProps, { className: composeClassName, href: href }), content()));
    }
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }), content()));
};
var CellTitle = function (props) {
    var text = props.text, className = props.className, otherProps = __rest(props, ["text", "className"]);
    var composeClassName = cn('x-cell__title', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("h2", null, props.text)));
};
var Cell = function (props) {
    var arrow = props.arrow, indentLine = props.indentLine, endIndentLine = props.endIndentLine, dividerIndent = props.dividerIndent, className = props.className, children = props.children, onClick = props.onClick, _a = props.wrapperBorder, wrapperBorder = _a === void 0 ? true : _a, otherProps = __rest(props, ["arrow", "indentLine", "endIndentLine", "dividerIndent", "className", "children", "onClick", "wrapperBorder"]);
    if (indentLine || endIndentLine) {
        // TODO: 需要废弃这两个属性
        console.warn('indentLine与endIndentLine将被废弃，请使用dividerIndent代替');
    }
    // 兼容老的属性
    // TODO: indentLine 和 endIndentLine 废弃后，该部分代码需要一起删除
    var finalDividerIndent = dividerIndent;
    if (!finalDividerIndent && (indentLine || endIndentLine)) {
        if (indentLine && !endIndentLine) {
            finalDividerIndent = 'left';
        }
        else {
            finalDividerIndent = 'both';
        }
    }
    var composeClassName = cn('x-cell', { 'x-cell--no-border': !wrapperBorder }, className);
    var composeChildren = React.Children.toArray(children);
    return (React.createElement("section", __assign({}, otherProps, { className: composeClassName }), composeChildren.map(function (child, index) {
        if (child && child.type === CellRow) {
            return React.cloneElement(child, {
                key: index,
                arrow: child.props.arrow === false ? false : arrow || child.props.arrow,
                onClick: child.props.href || child.props.to ? void 0 : onClick || child.props.onClick,
                dividerIndent: finalDividerIndent,
            });
        }
        return child;
    })));
};
Cell.Row = CellRow;
Cell.Title = CellTitle;
export default Cell;

==> auto-ui-2.4.63.tgz: package/es/cell/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { Link } from 'react-router-dom';
import IconArrow from '../icon/arrow';
import './style/index.scss';
var CellRow = function (props) {
    var value = props.value, arrow = props.arrow, onClick = props.onClick, href = props.href, to = props.to, activable = props.activable, className = props.className, children = props.children, title = props.title, dividerIndent = props.dividerIndent, indentLine = props.indentLine, endIndentLine = props.endIndentLine, addonAfter = props.addonAfter, otherProps = __rest(props, ["value", "arrow", "onClick", "href", "to", "activable", "className", "children", "title", "dividerIndent", "indentLine", "endIndentLine", "addonAfter"]);
    if (indentLine || endIndentLine) {
        // TODO: 需要废弃这两个属性
        console.warn('indentLine与endIndentLine将被废弃，请使用dividerIndent代替');
    }
    // 兼容老的属性
    // TODO: indentLine 和 endIndentLine 废弃后，该部分代码需要一起删除
    var finalDividerIndent = dividerIndent;
    if (!finalDividerIndent && (indentLine || endIndentLine)) {
        if (indentLine && !endIndentLine) {
            finalDividerIndent = 'left';
        }
        else {
            finalDividerIndent = 'both';
        }
    }
    var composeClassName = cn('x-cell__row', className, {
        'x-cell__row--activable': onClick || to || href || activable,
        'x-cell__row--arrow': arrow,
        'x-cell__row--divider-indent-left': finalDividerIndent === 'left',
        'x-cell__row--divider-indent-both': finalDividerIndent === 'both',
    });
    var content = function () { return (React.createElement(React.Fragment, null,
        title && React.createElement("label", null, title),
        children,
        addonAfter && React.createElement("span", { className: "x-cell__addon-after" }, addonAfter),
        arrow && React.createElement(IconArrow, { className: "x-cell__arrow" }))); };
    if (onClick) {
        var onClickHandle = function () { return onClick(value); };
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, onClick: onClickHandle }), content()));
    }
    if (to) {
        return (React.createElement(Link, __assign({}, otherProps, { className: composeClassName, to: to }), content()));
    }
    if (href) {
        return (React.createElement("a", __assign({}, otherProps, { className: composeClassName, href: href }), content()));
    }
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }), content()));
};
var CellTitle = function (props) {
    var text = props.text, className = props.className, otherProps = __rest(props, ["text", "className"]);
    var composeClassName = cn('x-cell__title', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("h2", null, props.text)));
};
var Cell = function (props) {
    var arrow = props.arrow, indentLine = props.indentLine, endIndentLine = props.endIndentLine, dividerIndent = props.dividerIndent, className = props.className, children = props.children, onClick = props.onClick, _a = props.wrapperBorder, wrapperBorder = _a === void 0 ? true : _a, otherProps = __rest(props, ["arrow", "indentLine", "endIndentLine", "dividerIndent", "className", "children", "onClick", "wrapperBorder"]);
    if (indentLine || endIndentLine) {
        // TODO: 需要废弃这两个属性
        console.warn('indentLine与endIndentLine将被废弃，请使用dividerIndent代替');
    }
    // 兼容老的属性
    // TODO: indentLine 和 endIndentLine 废弃后，该部分代码需要一起删除
    var finalDividerIndent = dividerIndent;
    if (!finalDividerIndent && (indentLine || endIndentLine)) {
        if (indentLine && !endIndentLine) {
            finalDividerIndent = 'left';
        }
        else {
            finalDividerIndent = 'both';
        }
    }
    var composeClassName = cn('x-cell', { 'x-cell--no-border': !wrapperBorder }, className);
    var composeChildren = React.Children.toArray(children);
    return (React.createElement("section", __assign({}, otherProps, { className: composeClassName }), composeChildren.map(function (child, index) {
        if (child && child.type === CellRow) {
            return React.cloneElement(child, {
                key: index,
                arrow: child.props.arrow === false ? false : arrow || child.props.arrow,
                onClick: child.props.href || child.props.to ? void 0 : onClick || child.props.onClick,
                dividerIndent: finalDividerIndent,
            });
        }
        return child;
    })));
};
Cell.Row = CellRow;
Cell.Title = CellTitle;
export default Cell;
